==> rdfadict-0.3.1.tar.gz: rdfadict-0.3.1/src/rdfadict/sink/__init__.py <==
## Copyright (c) 2006-2007 Nathan R. Yergler, Creative Commons

## Permission is hereby granted, free of charge, to any person obtaining
## a copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:

## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.

## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.

"""Simply triple Sink objects."""

class SimpleTripleSink(list):
    """A bare-bones Triple sink that just stores them as a list of tuples."""

    def triple(self, s, p, o):

        self.append( (s,p,o) )

class DictTripleSink(dict):

    def triple(self, s, p, o):
        """Add a triple [s, p, o] to the triple dictionary."""

        self.setdefault(s, {}).setdefault(p, [])
        self[s][p].append(o)

==> rdfadict-0.5.2.tar.gz: rdfadict-0.5.2/src/rdfadict/sink/__init__.py <==
## Copyright (c) 2006-2007 Nathan R. Yergler, Creative Commons

## Permission is hereby granted, free of charge, to any person obtaining
## a copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:

## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.

## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
## AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.

"""Simple triple Sink objects."""

class SimpleTripleSink(list):
    """A bare-bones Triple sink that just stores them as a list of tuples."""

    def triple(self, s, p, o):

        self.append( (str(s),str(p),str(o)) )

class DictTripleSink(dict):

    def triple(self, s, p, o):
        """Add a triple [s, p, o] to the triple dictionary."""

        self.setdefault(str(s), {}).setdefault(str(p), [])
        self[str(s)][str(p)].append(str(o))
